pub enum RustGenError {
Unsupported {
what: &'static str,
at: usize,
},
InvalidAnnotation {
name: String,
reason: &'static str,
},
UnresolvedType {
scoped: String,
},
}Expand description
Error while generating Rust code from the IDL AST.
Variants
Unsupported
The IDL construct is currently not supported by the Rust codegen.
Not a spec bug — some IDL features (Fixed, Map, Any, Bitset, Bitmask, Valuetype, Interface, Component, Home) are outside the DDS-DataType path. Whoever generates DDS DataTypes does not need them.
Fields
InvalidAnnotation
The annotation value could not be evaluated.
UnresolvedType
The type reference could not be resolved.